@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2020 Dean Miller for Adafruit Industries
 #
-# Copyright (c) 2017 Dean Miller for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_as726x`
 ====================================================
@@ -117,9 +100,7 @@ _COLOR_REGS_CALIBRATED = (
 
 
 class AS726x:
-    """AS726x spectral sensor base class.
-
-       """
+    """AS726x spectral sensor base class."""
 
     MODE_0 = 0b00
     """Continuously gather samples of violet, blue, green and yellow. Orange and red are skipped
@@ -204,10 +185,10 @@ class AS726x:
     def driver_led_current(self):
         """The current limit for the driver LED in milliamps. One of:
 
-           - 12.5 mA
-           - 25 mA
-           - 50 mA
-           - 100 mA"""
+        - 12.5 mA
+        - 25 mA
+        - 50 mA
+        - 100 mA"""
         return self._driver_led_current
 
     @driver_led_current.setter
@@ -226,10 +207,10 @@ class AS726x:
     def indicator_led_current(self):
         """The current limit for the indicator LED in milliamps. One of:
 
-           - 1 mA
-           - 2 mA
-           - 4 mA
-           - 8 mA"""
+        - 1 mA
+        - 2 mA
+        - 4 mA
+        - 8 mA"""
         return self._indicator_led_current
 
     @indicator_led_current.setter
@@ -248,10 +229,10 @@ class AS726x:
     def conversion_mode(self):
         """The conversion mode. One of:
 
-           - `MODE_0`
-           - `MODE_1`
-           - `MODE_2`
-           - `ONE_SHOT`"""
+        - `MODE_0`
+        - `MODE_1`
+        - `MODE_2`
+        - `ONE_SHOT`"""
         return self._conversion_mode
 
     @conversion_mode.setter
@@ -300,8 +281,8 @@ class AS726x:
     def start_measurement(self):
         """Begin a measurement.
 
-           This will set the device to One Shot mode and values will not change after `data_ready`
-           until `start_measurement` is called again or the `conversion_mode` is changed."""
+        This will set the device to One Shot mode and values will not change after `data_ready`
+        until `start_measurement` is called again or the `conversion_mode` is changed."""
         state = self._virtual_read(_AS726X_CONTROL_SETUP)
         state &= ~(0x02)
         self._virtual_write(_AS726X_CONTROL_SETUP, state)
@@ -401,8 +382,8 @@ class AS726x:
 class AS726x_I2C(AS726x):
     """AS726x spectral sensor via I2C.
 
-       :param ~busio.I2C i2c_bus: The I2C bus connected to the sensor
-       """
+    :param ~busio.I2C i2c_bus: The I2C bus connected to the sensor
+    """
 
     def __init__(self, i2c_bus, address=_AS726X_ADDRESS):
         self.i2c_device = I2CDevice(i2c_bus, address)
@@ -467,8 +448,8 @@ class AS726x_I2C(AS726x):
 class AS726x_UART(AS726x):
     """AS726x spectral sensor via UART.
 
-       :param ~busio.UART uart: The UART connected to the sensor
-       """
+    :param ~busio.UART uart: The UART connected to the sensor
+    """
 
     def __init__(self, uart):
         self._uart = uart
